# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.pool_incentives.v1beta1 import query_pb2 as osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GaugeIds = channel.unary_unary(
                '/osmosis.poolincentives.v1beta1.Query/GaugeIds',
                request_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryGaugeIdsRequest.SerializeToString,
                response_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryGaugeIdsResponse.FromString,
                )
        self.DistrInfo = channel.unary_unary(
                '/osmosis.poolincentives.v1beta1.Query/DistrInfo',
                request_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryDistrInfoRequest.SerializeToString,
                response_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryDistrInfoResponse.FromString,
                )
        self.Params = channel.unary_unary(
                '/osmosis.poolincentives.v1beta1.Query/Params',
                request_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.LockableDurations = channel.unary_unary(
                '/osmosis.poolincentives.v1beta1.Query/LockableDurations',
                request_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryLockableDurationsRequest.SerializeToString,
                response_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryLockableDurationsResponse.FromString,
                )
        self.IncentivizedPools = channel.unary_unary(
                '/osmosis.poolincentives.v1beta1.Query/IncentivizedPools',
                request_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryIncentivizedPoolsRequest.SerializeToString,
                response_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryIncentivizedPoolsResponse.FromString,
                )
        self.ExternalIncentiveGauges = channel.unary_unary(
                '/osmosis.poolincentives.v1beta1.Query/ExternalIncentiveGauges',
                request_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryExternalIncentiveGaugesRequest.SerializeToString,
                response_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryExternalIncentiveGaugesResponse.FromString,
                )


class QueryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GaugeIds(self, request, context):
        """GaugeIds takes the pool id and returns the matching gauge ids and durations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DistrInfo(self, request, context):
        """DistrInfo returns the pool's matching gauge ids and weights.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params returns pool incentives params.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LockableDurations(self, request, context):
        """LockableDurations returns lock durations for pools.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IncentivizedPools(self, request, context):
        """IncentivizedPools returns currently incentivized pools
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExternalIncentiveGauges(self, request, context):
        """ExternalIncentiveGauges returns external incentive gauges.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GaugeIds': grpc.unary_unary_rpc_method_handler(
                    servicer.GaugeIds,
                    request_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryGaugeIdsRequest.FromString,
                    response_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryGaugeIdsResponse.SerializeToString,
            ),
            'DistrInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.DistrInfo,
                    request_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryDistrInfoRequest.FromString,
                    response_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryDistrInfoResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'LockableDurations': grpc.unary_unary_rpc_method_handler(
                    servicer.LockableDurations,
                    request_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryLockableDurationsRequest.FromString,
                    response_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryLockableDurationsResponse.SerializeToString,
            ),
            'IncentivizedPools': grpc.unary_unary_rpc_method_handler(
                    servicer.IncentivizedPools,
                    request_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryIncentivizedPoolsRequest.FromString,
                    response_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryIncentivizedPoolsResponse.SerializeToString,
            ),
            'ExternalIncentiveGauges': grpc.unary_unary_rpc_method_handler(
                    servicer.ExternalIncentiveGauges,
                    request_deserializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryExternalIncentiveGaugesRequest.FromString,
                    response_serializer=osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryExternalIncentiveGaugesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.poolincentives.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GaugeIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.poolincentives.v1beta1.Query/GaugeIds',
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryGaugeIdsRequest.SerializeToString,
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryGaugeIdsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DistrInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.poolincentives.v1beta1.Query/DistrInfo',
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryDistrInfoRequest.SerializeToString,
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryDistrInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.poolincentives.v1beta1.Query/Params',
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LockableDurations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.poolincentives.v1beta1.Query/LockableDurations',
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryLockableDurationsRequest.SerializeToString,
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryLockableDurationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IncentivizedPools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.poolincentives.v1beta1.Query/IncentivizedPools',
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryIncentivizedPoolsRequest.SerializeToString,
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryIncentivizedPoolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExternalIncentiveGauges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.poolincentives.v1beta1.Query/ExternalIncentiveGauges',
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryExternalIncentiveGaugesRequest.SerializeToString,
            osmosis_dot_pool__incentives_dot_v1beta1_dot_query__pb2.QueryExternalIncentiveGaugesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/downtime-detector/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.downtime_detector.v1beta1 import genesis_pb2 as osmosis_dot_downtime__detector_dot_v1beta1_dot_genesis__pb2
from osmosis.downtime_detector.v1beta1 import downtime_duration_pb2 as osmosis_dot_downtime__detector_dot_v1beta1_dot_downtime__duration__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-osmosis/downtime-detector/v1beta1/query.proto\x12 osmosis.downtimedetector.v1beta1\x1a\x14gogoproto/gogo.proto\x1a/osmosis/downtime-detector/v1beta1/genesis.proto\x1a\x39osmosis/downtime-detector/v1beta1/downtime_duration.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcd\x01\n%RecoveredSinceDowntimeOfLengthRequest\x12Q\n\x08\x64owntime\x18\x01 \x01(\x0e\x32*.osmosis.downtimedetector.v1beta1.DowntimeB\x13\xf2\xde\x1f\x0fyaml:\"downtime\"\x12Q\n\x08recovery\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB$\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x18yaml:\"recovery_duration\"\"G\n&RecoveredSinceDowntimeOfLengthResponse\x12\x1d\n\x15succesfully_recovered\x18\x01 \x01(\x08\x32\x88\x02\n\x05Query\x12\xfe\x01\n\x1eRecoveredSinceDowntimeOfLength\x12G.osmosis.downtimedetector.v1beta1.RecoveredSinceDowntimeOfLengthRequest\x1aH.osmosis.downtimedetector.v1beta1.RecoveredSinceDowntimeOfLengthResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/osmosis/downtime-detector/v1beta1/RecoveredSinceDowntimeOfLengthBKZIgithub.com/osmosis-labs/osmosis/v14/x/downtime-detector/client/queryprotob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.downtime_detector.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/osmosis-labs/osmosis/v14/x/downtime-detector/client/queryproto'
  _RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST.fields_by_name['downtime']._options = None
  _RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST.fields_by_name['downtime']._serialized_options = b'\362\336\037\017yaml:\"downtime\"'
  _RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST.fields_by_name['recovery']._options = None
  _RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST.fields_by_name['recovery']._serialized_options = b'\310\336\037\000\230\337\037\001\362\336\037\030yaml:\"recovery_duration\"'
  _QUERY.methods_by_name['RecoveredSinceDowntimeOfLength']._options = None
  _QUERY.methods_by_name['RecoveredSinceDowntimeOfLength']._serialized_options = b'\202\323\344\223\002C\022A/osmosis/downtime-detector/v1beta1/RecoveredSinceDowntimeOfLength'
  _RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST._serialized_start=439
  _RECOVEREDSINCEDOWNTIMEOFLENGTHREQUEST._serialized_end=644
  _RECOVEREDSINCEDOWNTIMEOFLENGTHRESPONSE._serialized_start=646
  _RECOVEREDSINCEDOWNTIMEOFLENGTHRESPONSE._serialized_end=717
  _QUERY._serialized_start=720
  _QUERY._serialized_end=984
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.abci.v1beta1.abci_pb2
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.tx.v1beta1.tx_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _OrderBy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OrderByEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OrderBy.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ORDER_BY_UNSPECIFIED: _OrderBy.ValueType  # 0
    """ORDER_BY_UNSPECIFIED specifies an unknown sorting order. OrderBy defaults to ASC in this case."""
    ORDER_BY_ASC: _OrderBy.ValueType  # 1
    """ORDER_BY_ASC defines ascending order"""
    ORDER_BY_DESC: _OrderBy.ValueType  # 2
    """ORDER_BY_DESC defines descending order"""

class OrderBy(_OrderBy, metaclass=_OrderByEnumTypeWrapper):
    """OrderBy defines the sorting order"""

ORDER_BY_UNSPECIFIED: OrderBy.ValueType  # 0
"""ORDER_BY_UNSPECIFIED specifies an unknown sorting order. OrderBy defaults to ASC in this case."""
ORDER_BY_ASC: OrderBy.ValueType  # 1
"""ORDER_BY_ASC defines ascending order"""
ORDER_BY_DESC: OrderBy.ValueType  # 2
"""ORDER_BY_DESC defines descending order"""
global___OrderBy = OrderBy

class _BroadcastMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BroadcastModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BroadcastMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BROADCAST_MODE_UNSPECIFIED: _BroadcastMode.ValueType  # 0
    """zero-value for mode ordering"""
    BROADCAST_MODE_BLOCK: _BroadcastMode.ValueType  # 1
    """BROADCAST_MODE_BLOCK defines a tx broadcasting mode where the client waits for
    the tx to be committed in a block.
    """
    BROADCAST_MODE_SYNC: _BroadcastMode.ValueType  # 2
    """BROADCAST_MODE_SYNC defines a tx broadcasting mode where the client waits for
    a CheckTx execution response only.
    """
    BROADCAST_MODE_ASYNC: _BroadcastMode.ValueType  # 3
    """BROADCAST_MODE_ASYNC defines a tx broadcasting mode where the client returns
    immediately.
    """

class BroadcastMode(_BroadcastMode, metaclass=_BroadcastModeEnumTypeWrapper):
    """BroadcastMode specifies the broadcast mode for the TxService.Broadcast RPC method."""

BROADCAST_MODE_UNSPECIFIED: BroadcastMode.ValueType  # 0
"""zero-value for mode ordering"""
BROADCAST_MODE_BLOCK: BroadcastMode.ValueType  # 1
"""BROADCAST_MODE_BLOCK defines a tx broadcasting mode where the client waits for
the tx to be committed in a block.
"""
BROADCAST_MODE_SYNC: BroadcastMode.ValueType  # 2
"""BROADCAST_MODE_SYNC defines a tx broadcasting mode where the client waits for
a CheckTx execution response only.
"""
BROADCAST_MODE_ASYNC: BroadcastMode.ValueType  # 3
"""BROADCAST_MODE_ASYNC defines a tx broadcasting mode where the client returns
immediately.
"""
global___BroadcastMode = BroadcastMode

@typing_extensions.final
class GetTxsEventRequest(google.protobuf.message.Message):
    """GetTxsEventRequest is the request type for the Service.TxsByEvents
    RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """events is the list of transaction event type."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
    order_by: global___OrderBy.ValueType
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[builtins.str] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
        order_by: global___OrderBy.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events", "order_by", b"order_by", "pagination", b"pagination"]) -> None: ...

global___GetTxsEventRequest = GetTxsEventRequest

@typing_extensions.final
class GetTxsEventResponse(google.protobuf.message.Message):
    """GetTxsEventResponse is the response type for the Service.TxsByEvents
    RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TXS_FIELD_NUMBER: builtins.int
    TX_RESPONSES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def txs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.tx.v1beta1.tx_pb2.Tx]:
        """txs is the list of queried transactions."""
    @property
    def tx_responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.abci.v1beta1.abci_pb2.TxResponse]:
        """tx_responses is the list of queried TxResponses."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
    def __init__(
        self,
        *,
        txs: collections.abc.Iterable[cosmos.tx.v1beta1.tx_pb2.Tx] | None = ...,
        tx_responses: collections.abc.Iterable[cosmos.base.abci.v1beta1.abci_pb2.TxResponse] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "tx_responses", b"tx_responses", "txs", b"txs"]) -> None: ...

global___GetTxsEventResponse = GetTxsEventResponse

@typing_extensions.final
class BroadcastTxRequest(google.protobuf.message.Message):
    """BroadcastTxRequest is the request type for the Service.BroadcastTxRequest
    RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TX_BYTES_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    tx_bytes: builtins.bytes
    """tx_bytes is the raw transaction."""
    mode: global___BroadcastMode.ValueType
    def __init__(
        self,
        *,
        tx_bytes: builtins.bytes = ...,
        mode: global___BroadcastMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode", "tx_bytes", b"tx_bytes"]) -> None: ...

global___BroadcastTxRequest = BroadcastTxRequest

@typing_extensions.final
class BroadcastTxResponse(google.protobuf.message.Message):
    """BroadcastTxResponse is the response type for the
    Service.BroadcastTx method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TX_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def tx_response(self) -> cosmos.base.abci.v1beta1.abci_pb2.TxResponse:
        """tx_response is the queried TxResponses."""
    def __init__(
        self,
        *,
        tx_response: cosmos.base.abci.v1beta1.abci_pb2.TxResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tx_response", b"tx_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tx_response", b"tx_response"]) -> None: ...

global___BroadcastTxResponse = BroadcastTxResponse

@typing_extensions.final
class SimulateRequest(google.protobuf.message.Message):
    """SimulateRequest is the request type for the Service.Simulate
    RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TX_FIELD_NUMBER: builtins.int
    TX_BYTES_FIELD_NUMBER: builtins.int
    @property
    def tx(self) -> cosmos.tx.v1beta1.tx_pb2.Tx:
        """tx is the transaction to simulate.
        Deprecated. Send raw tx bytes instead.
        """
    tx_bytes: builtins.bytes
    """tx_bytes is the raw transaction.

    Since: cosmos-sdk 0.43
    """
    def __init__(
        self,
        *,
        tx: cosmos.tx.v1beta1.tx_pb2.Tx | None = ...,
        tx_bytes: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tx", b"tx"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tx", b"tx", "tx_bytes", b"tx_bytes"]) -> None: ...

global___SimulateRequest = SimulateRequest

@typing_extensions.final
class SimulateResponse(google.protobuf.message.Message):
    """SimulateResponse is the response type for the
    Service.SimulateRPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GAS_INFO_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    @property
    def gas_info(self) -> cosmos.base.abci.v1beta1.abci_pb2.GasInfo:
        """gas_info is the information about gas used in the simulation."""
    @property
    def result(self) -> cosmos.base.abci.v1beta1.abci_pb2.Result:
        """result is the result of the simulation."""
    def __init__(
        self,
        *,
        gas_info: cosmos.base.abci.v1beta1.abci_pb2.GasInfo | None = ...,
        result: cosmos.base.abci.v1beta1.abci_pb2.Result | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gas_info", b"gas_info", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gas_info", b"gas_info", "result", b"result"]) -> None: ...

global___SimulateResponse = SimulateResponse

@typing_extensions.final
class GetTxRequest(google.protobuf.message.Message):
    """GetTxRequest is the request type for the Service.GetTx
    RPC method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HASH_FIELD_NUMBER: builtins.int
    hash: builtins.str
    """hash is the tx hash to query, encoded as a hex string."""
    def __init__(
        self,
        *,
        hash: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash", b"hash"]) -> None: ...

global___GetTxRequest = GetTxRequest

@typing_extensions.final
class GetTxResponse(google.protobuf.message.Message):
    """GetTxResponse is the response type for the Service.GetTx method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TX_FIELD_NUMBER: builtins.int
    TX_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def tx(self) -> cosmos.tx.v1beta1.tx_pb2.Tx:
        """tx is the queried transaction."""
    @property
    def tx_response(self) -> cosmos.base.abci.v1beta1.abci_pb2.TxResponse:
        """tx_response is the queried TxResponses."""
    def __init__(
        self,
        *,
        tx: cosmos.tx.v1beta1.tx_pb2.Tx | None = ...,
        tx_response: cosmos.base.abci.v1beta1.abci_pb2.TxResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tx", b"tx", "tx_response", b"tx_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tx", b"tx", "tx_response", b"tx_response"]) -> None: ...

global___GetTxResponse = GetTxResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/txfees/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from osmosis.txfees.v1beta1 import feetoken_pb2 as osmosis_dot_txfees_dot_v1beta1_dot_feetoken__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"osmosis/txfees/v1beta1/query.proto\x12\x16osmosis.txfees.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a%osmosis/txfees/v1beta1/feetoken.proto\"\x17\n\x15QueryFeeTokensRequest\"i\n\x16QueryFeeTokensResponse\x12O\n\nfee_tokens\x18\x01 \x03(\x0b\x32 .osmosis.txfees.v1beta1.FeeTokenB\x19\xf2\xde\x1f\x11yaml:\"fee_tokens\"\xc8\xde\x1f\x00\"=\n\x1aQueryDenomSpotPriceRequest\x12\x1f\n\x05\x64\x65nom\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"denom\"\"\x9a\x01\n\x1bQueryDenomSpotPriceResponse\x12\"\n\x06poolID\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12W\n\nspot_price\x18\x02 \x01(\tBC\xf2\xde\x1f\x11yaml:\"spot_price\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\":\n\x17QueryDenomPoolIdRequest\x12\x1f\n\x05\x64\x65nom\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"denom\"\">\n\x18QueryDenomPoolIdResponse\x12\"\n\x06poolID\x18\x01 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\"\x17\n\x15QueryBaseDenomRequest\"C\n\x16QueryBaseDenomResponse\x12)\n\nbase_denom\x18\x01 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"base_denom\"2\x94\x05\n\x05Query\x12\x96\x01\n\tFeeTokens\x12-.osmosis.txfees.v1beta1.QueryFeeTokensRequest\x1a..osmosis.txfees.v1beta1.QueryFeeTokensResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/osmosis/txfees/v1beta1/fee_tokens\x12\xae\x01\n\x0e\x44\x65nomSpotPrice\x12\x32.osmosis.txfees.v1beta1.QueryDenomSpotPriceRequest\x1a\x33.osmosis.txfees.v1beta1.QueryDenomSpotPriceResponse\"3\x82\xd3\xe4\x93\x02-\x12+/osmosis/txfees/v1beta1/spot_price_by_denom\x12\xa7\x01\n\x0b\x44\x65nomPoolId\x12/.osmosis.txfees.v1beta1.QueryDenomPoolIdRequest\x1a\x30.osmosis.txfees.v1beta1.QueryDenomPoolIdResponse\"5\x82\xd3\xe4\x93\x02/\x12-/osmosis/txfees/v1beta1/denom_pool_id/{denom}\x12\x96\x01\n\tBaseDenom\x12-.osmosis.txfees.v1beta1.QueryBaseDenomRequest\x1a..osmosis.txfees.v1beta1.QueryBaseDenomResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/osmosis/txfees/v1beta1/base_denomB4Z2github.com/osmosis-labs/osmosis/v14/x/txfees/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.txfees.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/osmosis-labs/osmosis/v14/x/txfees/types'
  _QUERYFEETOKENSRESPONSE.fields_by_name['fee_tokens']._options = None
  _QUERYFEETOKENSRESPONSE.fields_by_name['fee_tokens']._serialized_options = b'\362\336\037\021yaml:\"fee_tokens\"\310\336\037\000'
  _QUERYDENOMSPOTPRICEREQUEST.fields_by_name['denom']._options = None
  _QUERYDENOMSPOTPRICEREQUEST.fields_by_name['denom']._serialized_options = b'\362\336\037\014yaml:\"denom\"'
  _QUERYDENOMSPOTPRICERESPONSE.fields_by_name['poolID']._options = None
  _QUERYDENOMSPOTPRICERESPONSE.fields_by_name['poolID']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYDENOMSPOTPRICERESPONSE.fields_by_name['spot_price']._options = None
  _QUERYDENOMSPOTPRICERESPONSE.fields_by_name['spot_price']._serialized_options = b'\362\336\037\021yaml:\"spot_price\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYDENOMPOOLIDREQUEST.fields_by_name['denom']._options = None
  _QUERYDENOMPOOLIDREQUEST.fields_by_name['denom']._serialized_options = b'\362\336\037\014yaml:\"denom\"'
  _QUERYDENOMPOOLIDRESPONSE.fields_by_name['poolID']._options = None
  _QUERYDENOMPOOLIDRESPONSE.fields_by_name['poolID']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
  _QUERYBASEDENOMRESPONSE.fields_by_name['base_denom']._options = None
  _QUERYBASEDENOMRESPONSE.fields_by_name['base_denom']._serialized_options = b'\362\336\037\021yaml:\"base_denom\"'
  _QUERY.methods_by_name['FeeTokens']._options = None
  _QUERY.methods_by_name['FeeTokens']._serialized_options = b'\202\323\344\223\002$\022\"/osmosis/txfees/v1beta1/fee_tokens'
  _QUERY.methods_by_name['DenomSpotPrice']._options = None
  _QUERY.methods_by_name['DenomSpotPrice']._serialized_options = b'\202\323\344\223\002-\022+/osmosis/txfees/v1beta1/spot_price_by_denom'
  _QUERY.methods_by_name['DenomPoolId']._options = None
  _QUERY.methods_by_name['DenomPoolId']._serialized_options = b'\202\323\344\223\002/\022-/osmosis/txfees/v1beta1/denom_pool_id/{denom}'
  _QUERY.methods_by_name['BaseDenom']._options = None
  _QUERY.methods_by_name['BaseDenom']._serialized_options = b'\202\323\344\223\002$\022\"/osmosis/txfees/v1beta1/base_denom'
  _QUERYFEETOKENSREQUEST._serialized_start=185
  _QUERYFEETOKENSREQUEST._serialized_end=208
  _QUERYFEETOKENSRESPONSE._serialized_start=210
  _QUERYFEETOKENSRESPONSE._serialized_end=315
  _QUERYDENOMSPOTPRICEREQUEST._serialized_start=317
  _QUERYDENOMSPOTPRICEREQUEST._serialized_end=378
  _QUERYDENOMSPOTPRICERESPONSE._serialized_start=381
  _QUERYDENOMSPOTPRICERESPONSE._serialized_end=535
  _QUERYDENOMPOOLIDREQUEST._serialized_start=537
  _QUERYDENOMPOOLIDREQUEST._serialized_end=595
  _QUERYDENOMPOOLIDRESPONSE._serialized_start=597
  _QUERYDENOMPOOLIDRESPONSE._serialized_end=659
  _QUERYBASEDENOMREQUEST._serialized_start=661
  _QUERYBASEDENOMREQUEST._serialized_end=684
  _QUERYBASEDENOMRESPONSE._serialized_start=686
  _QUERYBASEDENOMRESPONSE._serialized_end=753
  _QUERY._serialized_start=756
  _QUERY._serialized_end=1416
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Params(google.protobuf.message.Message):
    """Params defines the set of params for the distribution module."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_TAX_FIELD_NUMBER: builtins.int
    BASE_PROPOSER_REWARD_FIELD_NUMBER: builtins.int
    BONUS_PROPOSER_REWARD_FIELD_NUMBER: builtins.int
    WITHDRAW_ADDR_ENABLED_FIELD_NUMBER: builtins.int
    community_tax: builtins.str
    base_proposer_reward: builtins.str
    bonus_proposer_reward: builtins.str
    withdraw_addr_enabled: builtins.bool
    def __init__(
        self,
        *,
        community_tax: builtins.str = ...,
        base_proposer_reward: builtins.str = ...,
        bonus_proposer_reward: builtins.str = ...,
        withdraw_addr_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_proposer_reward", b"base_proposer_reward", "bonus_proposer_reward", b"bonus_proposer_reward", "community_tax", b"community_tax", "withdraw_addr_enabled", b"withdraw_addr_enabled"]) -> None: ...

global___Params = Params

@typing_extensions.final
class ValidatorHistoricalRewards(google.protobuf.message.Message):
    """ValidatorHistoricalRewards represents historical rewards for a validator.
    Height is implicit within the store key.
    Cumulative reward ratio is the sum from the zeroeth period
    until this period of rewards / tokens, per the spec.
    The reference count indicates the number of objects
    which might need to reference this historical entry at any point.
    ReferenceCount =
       number of outstanding delegations which ended the associated period (and
       might need to read that record)
     + number of slashes which ended the associated period (and might need to
     read that record)
     + one per validator for the zeroeth period, set on initialization
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUMULATIVE_REWARD_RATIO_FIELD_NUMBER: builtins.int
    REFERENCE_COUNT_FIELD_NUMBER: builtins.int
    @property
    def cumulative_reward_ratio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...
    reference_count: builtins.int
    def __init__(
        self,
        *,
        cumulative_reward_ratio: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin] | None = ...,
        reference_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cumulative_reward_ratio", b"cumulative_reward_ratio", "reference_count", b"reference_count"]) -> None: ...

global___ValidatorHistoricalRewards = ValidatorHistoricalRewards

@typing_extensions.final
class ValidatorCurrentRewards(google.protobuf.message.Message):
    """ValidatorCurrentRewards represents current rewards and current
    period for a validator kept as a running counter and incremented
    each block as long as the validator's tokens remain constant.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REWARDS_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    @property
    def rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...
    period: builtins.int
    def __init__(
        self,
        *,
        rewards: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin] | None = ...,
        period: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["period", b"period", "rewards", b"rewards"]) -> None: ...

global___ValidatorCurrentRewards = ValidatorCurrentRewards

@typing_extensions.final
class ValidatorAccumulatedCommission(google.protobuf.message.Message):
    """ValidatorAccumulatedCommission represents accumulated commission
    for a validator kept as a running counter, can be withdrawn at any time.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMISSION_FIELD_NUMBER: builtins.int
    @property
    def commission(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...
    def __init__(
        self,
        *,
        commission: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commission", b"commission"]) -> None: ...

global___ValidatorAccumulatedCommission = ValidatorAccumulatedCommission

@typing_extensions.final
class ValidatorOutstandingRewards(google.protobuf.message.Message):
    """ValidatorOutstandingRewards represents outstanding (un-withdrawn) rewards
    for a validator inexpensive to track, allows simple sanity checks.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REWARDS_FIELD_NUMBER: builtins.int
    @property
    def rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...
    def __init__(
        self,
        *,
        rewards: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rewards", b"rewards"]) -> None: ...

global___ValidatorOutstandingRewards = ValidatorOutstandingRewards

@typing_extensions.final
class ValidatorSlashEvent(google.protobuf.message.Message):
    """ValidatorSlashEvent represents a validator slash event.
    Height is implicit within the store key.
    This is needed to calculate appropriate amount of staking tokens
    for delegations which are withdrawn after a slash has occurred.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_PERIOD_FIELD_NUMBER: builtins.int
    FRACTION_FIELD_NUMBER: builtins.int
    validator_period: builtins.int
    fraction: builtins.str
    def __init__(
        self,
        *,
        validator_period: builtins.int = ...,
        fraction: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fraction", b"fraction", "validator_period", b"validator_period"]) -> None: ...

global___ValidatorSlashEvent = ValidatorSlashEvent

@typing_extensions.final
class ValidatorSlashEvents(google.protobuf.message.Message):
    """ValidatorSlashEvents is a collection of ValidatorSlashEvent messages."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_SLASH_EVENTS_FIELD_NUMBER: builtins.int
    @property
    def validator_slash_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorSlashEvent]: ...
    def __init__(
        self,
        *,
        validator_slash_events: collections.abc.Iterable[global___ValidatorSlashEvent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["validator_slash_events", b"validator_slash_events"]) -> None: ...

global___ValidatorSlashEvents = ValidatorSlashEvents

@typing_extensions.final
class FeePool(google.protobuf.message.Message):
    """FeePool is the global fee pool for distribution."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_POOL_FIELD_NUMBER: builtins.int
    @property
    def community_pool(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...
    def __init__(
        self,
        *,
        community_pool: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["community_pool", b"community_pool"]) -> None: ...

global___FeePool = FeePool

@typing_extensions.final
class CommunityPoolSpendProposal(google.protobuf.message.Message):
    """CommunityPoolSpendProposal details a proposal for use of community funds,
    together with how many coins are proposed to be spent, and to which
    recipient account.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RECIPIENT_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    recipient: builtins.str
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        recipient: builtins.str = ...,
        amount: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "description", b"description", "recipient", b"recipient", "title", b"title"]) -> None: ...

global___CommunityPoolSpendProposal = CommunityPoolSpendProposal

@typing_extensions.final
class DelegatorStartingInfo(google.protobuf.message.Message):
    """DelegatorStartingInfo represents the starting info for a delegator reward
    period. It tracks the previous validator period, the delegation's amount of
    staking token, and the creation height (to check later on if any slashes have
    occurred). NOTE: Even though validators are slashed to whole staking tokens,
    the delegators within the validator may be left with less than a full token,
    thus sdk.Dec is used.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREVIOUS_PERIOD_FIELD_NUMBER: builtins.int
    STAKE_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    previous_period: builtins.int
    stake: builtins.str
    height: builtins.int
    def __init__(
        self,
        *,
        previous_period: builtins.int = ...,
        stake: builtins.str = ...,
        height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "previous_period", b"previous_period", "stake", b"stake"]) -> None: ...

global___DelegatorStartingInfo = DelegatorStartingInfo

@typing_extensions.final
class DelegationDelegatorReward(google.protobuf.message.Message):
    """DelegationDelegatorReward represents the properties
    of a delegator's delegation reward.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    REWARD_FIELD_NUMBER: builtins.int
    validator_address: builtins.str
    @property
    def reward(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...
    def __init__(
        self,
        *,
        validator_address: builtins.str = ...,
        reward: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reward", b"reward", "validator_address", b"validator_address"]) -> None: ...

global___DelegationDelegatorReward = DelegationDelegatorReward

@typing_extensions.final
class CommunityPoolSpendProposalWithDeposit(google.protobuf.message.Message):
    """CommunityPoolSpendProposalWithDeposit defines a CommunityPoolSpendProposal
    with a deposit
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RECIPIENT_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    DEPOSIT_FIELD_NUMBER: builtins.int
    title: builtins.str
    description: builtins.str
    recipient: builtins.str
    amount: builtins.str
    deposit: builtins.str
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        description: builtins.str = ...,
        recipient: builtins.str = ...,
        amount: builtins.str = ...,
        deposit: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "deposit", b"deposit", "description", b"description", "recipient", b"recipient", "title", b"title"]) -> None: ...

global___CommunityPoolSpendProposalWithDeposit = CommunityPoolSpendProposalWithDeposit



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import cosmos.distribution.v1beta1.distribution_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DelegatorWithdrawInfo(google.protobuf.message.Message):
    """DelegatorWithdrawInfo is the address for where distributions rewards are
    withdrawn to by default this struct is only used at genesis to feed in
    default withdraw addresses.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    WITHDRAW_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    """delegator_address is the address of the delegator."""
    withdraw_address: builtins.str
    """withdraw_address is the address to withdraw the delegation rewards to."""
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        withdraw_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "withdraw_address", b"withdraw_address"]) -> None: ...

global___DelegatorWithdrawInfo = DelegatorWithdrawInfo

@typing_extensions.final
class ValidatorOutstandingRewardsRecord(google.protobuf.message.Message):
    """ValidatorOutstandingRewardsRecord is used for import/export via genesis json."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    OUTSTANDING_REWARDS_FIELD_NUMBER: builtins.int
    validator_address: builtins.str
    """validator_address is the address of the validator."""
    @property
    def outstanding_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]:
        """outstanding_rewards represents the oustanding rewards of a validator."""
    def __init__(
        self,
        *,
        validator_address: builtins.str = ...,
        outstanding_rewards: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["outstanding_rewards", b"outstanding_rewards", "validator_address", b"validator_address"]) -> None: ...

global___ValidatorOutstandingRewardsRecord = ValidatorOutstandingRewardsRecord

@typing_extensions.final
class ValidatorAccumulatedCommissionRecord(google.protobuf.message.Message):
    """ValidatorAccumulatedCommissionRecord is used for import / export via genesis
    json.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    ACCUMULATED_FIELD_NUMBER: builtins.int
    validator_address: builtins.str
    """validator_address is the address of the validator."""
    @property
    def accumulated(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorAccumulatedCommission:
        """accumulated is the accumulated commission of a validator."""
    def __init__(
        self,
        *,
        validator_address: builtins.str = ...,
        accumulated: cosmos.distribution.v1beta1.distribution_pb2.ValidatorAccumulatedCommission | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accumulated", b"accumulated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accumulated", b"accumulated", "validator_address", b"validator_address"]) -> None: ...

global___ValidatorAccumulatedCommissionRecord = ValidatorAccumulatedCommissionRecord

@typing_extensions.final
class ValidatorHistoricalRewardsRecord(google.protobuf.message.Message):
    """ValidatorHistoricalRewardsRecord is used for import / export via genesis
    json.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    REWARDS_FIELD_NUMBER: builtins.int
    validator_address: builtins.str
    """validator_address is the address of the validator."""
    period: builtins.int
    """period defines the period the historical rewards apply to."""
    @property
    def rewards(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorHistoricalRewards:
        """rewards defines the historical rewards of a validator."""
    def __init__(
        self,
        *,
        validator_address: builtins.str = ...,
        period: builtins.int = ...,
        rewards: cosmos.distribution.v1beta1.distribution_pb2.ValidatorHistoricalRewards | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rewards", b"rewards"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["period", b"period", "rewards", b"rewards", "validator_address", b"validator_address"]) -> None: ...

global___ValidatorHistoricalRewardsRecord = ValidatorHistoricalRewardsRecord

@typing_extensions.final
class ValidatorCurrentRewardsRecord(google.protobuf.message.Message):
    """ValidatorCurrentRewardsRecord is used for import / export via genesis json."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    REWARDS_FIELD_NUMBER: builtins.int
    validator_address: builtins.str
    """validator_address is the address of the validator."""
    @property
    def rewards(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorCurrentRewards:
        """rewards defines the current rewards of a validator."""
    def __init__(
        self,
        *,
        validator_address: builtins.str = ...,
        rewards: cosmos.distribution.v1beta1.distribution_pb2.ValidatorCurrentRewards | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rewards", b"rewards"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["rewards", b"rewards", "validator_address", b"validator_address"]) -> None: ...

global___ValidatorCurrentRewardsRecord = ValidatorCurrentRewardsRecord

@typing_extensions.final
class DelegatorStartingInfoRecord(google.protobuf.message.Message):
    """DelegatorStartingInfoRecord used for import / export via genesis json."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    STARTING_INFO_FIELD_NUMBER: builtins.int
    delegator_address: builtins.str
    """delegator_address is the address of the delegator."""
    validator_address: builtins.str
    """validator_address is the address of the validator."""
    @property
    def starting_info(self) -> cosmos.distribution.v1beta1.distribution_pb2.DelegatorStartingInfo:
        """starting_info defines the starting info of a delegator."""
    def __init__(
        self,
        *,
        delegator_address: builtins.str = ...,
        validator_address: builtins.str = ...,
        starting_info: cosmos.distribution.v1beta1.distribution_pb2.DelegatorStartingInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["starting_info", b"starting_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address", b"delegator_address", "starting_info", b"starting_info", "validator_address", b"validator_address"]) -> None: ...

global___DelegatorStartingInfoRecord = DelegatorStartingInfoRecord

@typing_extensions.final
class ValidatorSlashEventRecord(google.protobuf.message.Message):
    """ValidatorSlashEventRecord is used for import / export via genesis json."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    VALIDATOR_SLASH_EVENT_FIELD_NUMBER: builtins.int
    validator_address: builtins.str
    """validator_address is the address of the validator."""
    height: builtins.int
    """height defines the block height at which the slash event occured."""
    period: builtins.int
    """period is the period of the slash event."""
    @property
    def validator_slash_event(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorSlashEvent:
        """validator_slash_event describes the slash event."""
    def __init__(
        self,
        *,
        validator_address: builtins.str = ...,
        height: builtins.int = ...,
        period: builtins.int = ...,
        validator_slash_event: cosmos.distribution.v1beta1.distribution_pb2.ValidatorSlashEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["validator_slash_event", b"validator_slash_event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "period", b"period", "validator_address", b"validator_address", "validator_slash_event", b"validator_slash_event"]) -> None: ...

global___ValidatorSlashEventRecord = ValidatorSlashEventRecord

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the distribution module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    FEE_POOL_FIELD_NUMBER: builtins.int
    DELEGATOR_WITHDRAW_INFOS_FIELD_NUMBER: builtins.int
    PREVIOUS_PROPOSER_FIELD_NUMBER: builtins.int
    OUTSTANDING_REWARDS_FIELD_NUMBER: builtins.int
    VALIDATOR_ACCUMULATED_COMMISSIONS_FIELD_NUMBER: builtins.int
    VALIDATOR_HISTORICAL_REWARDS_FIELD_NUMBER: builtins.int
    VALIDATOR_CURRENT_REWARDS_FIELD_NUMBER: builtins.int
    DELEGATOR_STARTING_INFOS_FIELD_NUMBER: builtins.int
    VALIDATOR_SLASH_EVENTS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.distribution.v1beta1.distribution_pb2.Params:
        """params defines all the paramaters of the module."""
    @property
    def fee_pool(self) -> cosmos.distribution.v1beta1.distribution_pb2.FeePool:
        """fee_pool defines the fee pool at genesis."""
    @property
    def delegator_withdraw_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DelegatorWithdrawInfo]:
        """fee_pool defines the delegator withdraw infos at genesis."""
    previous_proposer: builtins.str
    """fee_pool defines the previous proposer at genesis."""
    @property
    def outstanding_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorOutstandingRewardsRecord]:
        """fee_pool defines the outstanding rewards of all validators at genesis."""
    @property
    def validator_accumulated_commissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorAccumulatedCommissionRecord]:
        """fee_pool defines the accumulated commisions of all validators at genesis."""
    @property
    def validator_historical_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorHistoricalRewardsRecord]:
        """fee_pool defines the historical rewards of all validators at genesis."""
    @property
    def validator_current_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorCurrentRewardsRecord]:
        """fee_pool defines the current rewards of all validators at genesis."""
    @property
    def delegator_starting_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DelegatorStartingInfoRecord]:
        """fee_pool defines the delegator starting infos at genesis."""
    @property
    def validator_slash_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorSlashEventRecord]:
        """fee_pool defines the validator slash events at genesis."""
    def __init__(
        self,
        *,
        params: cosmos.distribution.v1beta1.distribution_pb2.Params | None = ...,
        fee_pool: cosmos.distribution.v1beta1.distribution_pb2.FeePool | None = ...,
        delegator_withdraw_infos: collections.abc.Iterable[global___DelegatorWithdrawInfo] | None = ...,
        previous_proposer: builtins.str = ...,
        outstanding_rewards: collections.abc.Iterable[global___ValidatorOutstandingRewardsRecord] | None = ...,
        validator_accumulated_commissions: collections.abc.Iterable[global___ValidatorAccumulatedCommissionRecord] | None = ...,
        validator_historical_rewards: collections.abc.Iterable[global___ValidatorHistoricalRewardsRecord] | None = ...,
        validator_current_rewards: collections.abc.Iterable[global___ValidatorCurrentRewardsRecord] | None = ...,
        delegator_starting_infos: collections.abc.Iterable[global___DelegatorStartingInfoRecord] | None = ...,
        validator_slash_events: collections.abc.Iterable[global___ValidatorSlashEventRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fee_pool", b"fee_pool", "params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_starting_infos", b"delegator_starting_infos", "delegator_withdraw_infos", b"delegator_withdraw_infos", "fee_pool", b"fee_pool", "outstanding_rewards", b"outstanding_rewards", "params", b"params", "previous_proposer", b"previous_proposer", "validator_accumulated_commissions", b"validator_accumulated_commissions", "validator_current_rewards", b"validator_current_rewards", "validator_historical_rewards", b"validator_historical_rewards", "validator_slash_events", b"validator_slash_events"]) -> None: ...

global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Params(google.protobuf.message.Message):
    """Params defines the parameters for the bank module."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEND_ENABLED_FIELD_NUMBER: builtins.int
    DEFAULT_SEND_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def send_enabled(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SendEnabled]: ...
    default_send_enabled: builtins.bool
    def __init__(
        self,
        *,
        send_enabled: collections.abc.Iterable[global___SendEnabled] | None = ...,
        default_send_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_send_enabled", b"default_send_enabled", "send_enabled", b"send_enabled"]) -> None: ...

global___Params = Params

@typing_extensions.final
class SendEnabled(google.protobuf.message.Message):
    """SendEnabled maps coin denom to a send_enabled status (whether a denom is
    sendable).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    denom: builtins.str
    enabled: builtins.bool
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom", "enabled", b"enabled"]) -> None: ...

global___SendEnabled = SendEnabled

@typing_extensions.final
class Input(google.protobuf.message.Message):
    """Input models transaction input."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    address: builtins.str
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "coins", b"coins"]) -> None: ...

global___Input = Input

@typing_extensions.final
class Output(google.protobuf.message.Message):
    """Output models transaction outputs."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    address: builtins.str
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "coins", b"coins"]) -> None: ...

global___Output = Output

@typing_extensions.final
class Supply(google.protobuf.message.Message):
    """Supply represents a struct that passively keeps track of the total supply
    amounts in the network.
    This message is deprecated now that supply is indexed by denom.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_FIELD_NUMBER: builtins.int
    @property
    def total(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        total: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["total", b"total"]) -> None: ...

global___Supply = Supply

@typing_extensions.final
class DenomUnit(google.protobuf.message.Message):
    """DenomUnit represents a struct that describes a given
    denomination unit of the basic token.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    EXPONENT_FIELD_NUMBER: builtins.int
    ALIASES_FIELD_NUMBER: builtins.int
    denom: builtins.str
    """denom represents the string name of the given denom unit (e.g uatom)."""
    exponent: builtins.int
    """exponent represents power of 10 exponent that one must
    raise the base_denom to in order to equal the given DenomUnit's denom
    1 denom = 1^exponent base_denom
    (e.g. with a base_denom of uatom, one can create a DenomUnit of 'atom' with
    exponent = 6, thus: 1 atom = 10^6 uatom).
    """
    @property
    def aliases(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """aliases is a list of string aliases for the given denom"""
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        exponent: builtins.int = ...,
        aliases: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aliases", b"aliases", "denom", b"denom", "exponent", b"exponent"]) -> None: ...

global___DenomUnit = DenomUnit

@typing_extensions.final
class Metadata(google.protobuf.message.Message):
    """Metadata represents a struct that describes
    a basic token.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DENOM_UNITS_FIELD_NUMBER: builtins.int
    BASE_FIELD_NUMBER: builtins.int
    DISPLAY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SYMBOL_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def denom_units(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DenomUnit]:
        """denom_units represents the list of DenomUnit's for a given coin"""
    base: builtins.str
    """base represents the base denom (should be the DenomUnit with exponent = 0)."""
    display: builtins.str
    """display indicates the suggested denom that should be
    displayed in clients.
    """
    name: builtins.str
    """name defines the name of the token (eg: Cosmos Atom)

    Since: cosmos-sdk 0.43
    """
    symbol: builtins.str
    """symbol is the token symbol usually shown on exchanges (eg: ATOM). This can
    be the same as the display.

    Since: cosmos-sdk 0.43
    """
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        denom_units: collections.abc.Iterable[global___DenomUnit] | None = ...,
        base: builtins.str = ...,
        display: builtins.str = ...,
        name: builtins.str = ...,
        symbol: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base", b"base", "denom_units", b"denom_units", "description", b"description", "display", b"display", "name", b"name", "symbol", b"symbol"]) -> None: ...

global___Metadata = Metadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AuthorizationType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AuthorizationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AuthorizationType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AUTHORIZATION_TYPE_UNSPECIFIED: _AuthorizationType.ValueType  # 0
    """AUTHORIZATION_TYPE_UNSPECIFIED specifies an unknown authorization type"""
    AUTHORIZATION_TYPE_DELEGATE: _AuthorizationType.ValueType  # 1
    """AUTHORIZATION_TYPE_DELEGATE defines an authorization type for Msg/Delegate"""
    AUTHORIZATION_TYPE_UNDELEGATE: _AuthorizationType.ValueType  # 2
    """AUTHORIZATION_TYPE_UNDELEGATE defines an authorization type for Msg/Undelegate"""
    AUTHORIZATION_TYPE_REDELEGATE: _AuthorizationType.ValueType  # 3
    """AUTHORIZATION_TYPE_REDELEGATE defines an authorization type for Msg/BeginRedelegate"""

class AuthorizationType(_AuthorizationType, metaclass=_AuthorizationTypeEnumTypeWrapper):
    """AuthorizationType defines the type of staking module authorization type

    Since: cosmos-sdk 0.43
    """

AUTHORIZATION_TYPE_UNSPECIFIED: AuthorizationType.ValueType  # 0
"""AUTHORIZATION_TYPE_UNSPECIFIED specifies an unknown authorization type"""
AUTHORIZATION_TYPE_DELEGATE: AuthorizationType.ValueType  # 1
"""AUTHORIZATION_TYPE_DELEGATE defines an authorization type for Msg/Delegate"""
AUTHORIZATION_TYPE_UNDELEGATE: AuthorizationType.ValueType  # 2
"""AUTHORIZATION_TYPE_UNDELEGATE defines an authorization type for Msg/Undelegate"""
AUTHORIZATION_TYPE_REDELEGATE: AuthorizationType.ValueType  # 3
"""AUTHORIZATION_TYPE_REDELEGATE defines an authorization type for Msg/BeginRedelegate"""
global___AuthorizationType = AuthorizationType

@typing_extensions.final
class StakeAuthorization(google.protobuf.message.Message):
    """StakeAuthorization defines authorization for delegate/undelegate/redelegate.

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Validators(google.protobuf.message.Message):
        """Validators defines list of validator addresses."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ADDRESS_FIELD_NUMBER: builtins.int
        @property
        def address(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            address: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["address", b"address"]) -> None: ...

    MAX_TOKENS_FIELD_NUMBER: builtins.int
    ALLOW_LIST_FIELD_NUMBER: builtins.int
    DENY_LIST_FIELD_NUMBER: builtins.int
    AUTHORIZATION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def max_tokens(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """max_tokens specifies the maximum amount of tokens can be delegate to a validator. If it is
        empty, there is no spend limit and any amount of coins can be delegated.
        """
    @property
    def allow_list(self) -> global___StakeAuthorization.Validators:
        """allow_list specifies list of validator addresses to whom grantee can delegate tokens on behalf of granter's
        account.
        """
    @property
    def deny_list(self) -> global___StakeAuthorization.Validators:
        """deny_list specifies list of validator addresses to whom grantee can not delegate tokens."""
    authorization_type: global___AuthorizationType.ValueType
    """authorization_type defines one of AuthorizationType."""
    def __init__(
        self,
        *,
        max_tokens: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
        allow_list: global___StakeAuthorization.Validators | None = ...,
        deny_list: global___StakeAuthorization.Validators | None = ...,
        authorization_type: global___AuthorizationType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allow_list", b"allow_list", "deny_list", b"deny_list", "max_tokens", b"max_tokens", "validators", b"validators"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_list", b"allow_list", "authorization_type", b"authorization_type", "deny_list", b"deny_list", "max_tokens", b"max_tokens", "validators", b"validators"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["validators", b"validators"]) -> typing_extensions.Literal["allow_list", "deny_list"] | None: ...

global___StakeAuthorization = StakeAuthorization



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/lockup/params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bosmosis/lockup/params.proto\x12\x0eosmosis.lockup\x1a\x14gogoproto/gogo.proto\"Y\n\x06Params\x12O\n\x1e\x66orce_unlock_allowed_addresses\x18\x01 \x03(\tB\'\xf2\xde\x1f#yaml:\"force_unlock_allowed_address\"B4Z2github.com/osmosis-labs/osmosis/v14/x/lockup/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.lockup.params_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/osmosis-labs/osmosis/v14/x/lockup/types'
  _PARAMS.fields_by_name['force_unlock_allowed_addresses']._options = None
  _PARAMS.fields_by_name['force_unlock_allowed_addresses']._serialized_options = b'\362\336\037#yaml:\"force_unlock_allowed_address\"'
  _PARAMS._serialized_start=69
  _PARAMS._serialized_end=158
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.auth.v1beta1.auth_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BaseVestingAccount(google.protobuf.message.Message):
    """BaseVestingAccount implements the VestingAccount interface. It contains all
    the necessary fields needed for any vesting account implementation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_ACCOUNT_FIELD_NUMBER: builtins.int
    ORIGINAL_VESTING_FIELD_NUMBER: builtins.int
    DELEGATED_FREE_FIELD_NUMBER: builtins.int
    DELEGATED_VESTING_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    @property
    def base_account(self) -> cosmos.auth.v1beta1.auth_pb2.BaseAccount: ...
    @property
    def original_vesting(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    @property
    def delegated_free(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    @property
    def delegated_vesting(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    end_time: builtins.int
    def __init__(
        self,
        *,
        base_account: cosmos.auth.v1beta1.auth_pb2.BaseAccount | None = ...,
        original_vesting: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        delegated_free: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        delegated_vesting: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
        end_time: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_account", b"base_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_account", b"base_account", "delegated_free", b"delegated_free", "delegated_vesting", b"delegated_vesting", "end_time", b"end_time", "original_vesting", b"original_vesting"]) -> None: ...

global___BaseVestingAccount = BaseVestingAccount

@typing_extensions.final
class ContinuousVestingAccount(google.protobuf.message.Message):
    """ContinuousVestingAccount implements the VestingAccount interface. It
    continuously vests by unlocking coins linearly with respect to time.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_VESTING_ACCOUNT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    @property
    def base_vesting_account(self) -> global___BaseVestingAccount: ...
    start_time: builtins.int
    def __init__(
        self,
        *,
        base_vesting_account: global___BaseVestingAccount | None = ...,
        start_time: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_vesting_account", b"base_vesting_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_vesting_account", b"base_vesting_account", "start_time", b"start_time"]) -> None: ...

global___ContinuousVestingAccount = ContinuousVestingAccount

@typing_extensions.final
class DelayedVestingAccount(google.protobuf.message.Message):
    """DelayedVestingAccount implements the VestingAccount interface. It vests all
    coins after a specific time, but non prior. In other words, it keeps them
    locked until a specified time.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_VESTING_ACCOUNT_FIELD_NUMBER: builtins.int
    @property
    def base_vesting_account(self) -> global___BaseVestingAccount: ...
    def __init__(
        self,
        *,
        base_vesting_account: global___BaseVestingAccount | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_vesting_account", b"base_vesting_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_vesting_account", b"base_vesting_account"]) -> None: ...

global___DelayedVestingAccount = DelayedVestingAccount

@typing_extensions.final
class Period(google.protobuf.message.Message):
    """Period defines a length of time and amount of coins that will vest."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LENGTH_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    length: builtins.int
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        length: builtins.int = ...,
        amount: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "length", b"length"]) -> None: ...

global___Period = Period

@typing_extensions.final
class PeriodicVestingAccount(google.protobuf.message.Message):
    """PeriodicVestingAccount implements the VestingAccount interface. It
    periodically vests by unlocking coins during each specified period.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_VESTING_ACCOUNT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    VESTING_PERIODS_FIELD_NUMBER: builtins.int
    @property
    def base_vesting_account(self) -> global___BaseVestingAccount: ...
    start_time: builtins.int
    @property
    def vesting_periods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Period]: ...
    def __init__(
        self,
        *,
        base_vesting_account: global___BaseVestingAccount | None = ...,
        start_time: builtins.int = ...,
        vesting_periods: collections.abc.Iterable[global___Period] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_vesting_account", b"base_vesting_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_vesting_account", b"base_vesting_account", "start_time", b"start_time", "vesting_periods", b"vesting_periods"]) -> None: ...

global___PeriodicVestingAccount = PeriodicVestingAccount

@typing_extensions.final
class PermanentLockedAccount(google.protobuf.message.Message):
    """PermanentLockedAccount implements the VestingAccount interface. It does
    not ever release coins, locking them indefinitely. Coins in this account can
    still be used for delegating and for governance votes even while locked.

    Since: cosmos-sdk 0.43
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_VESTING_ACCOUNT_FIELD_NUMBER: builtins.int
    @property
    def base_vesting_account(self) -> global___BaseVestingAccount: ...
    def __init__(
        self,
        *,
        base_vesting_account: global___BaseVestingAccount | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_vesting_account", b"base_vesting_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_vesting_account", b"base_vesting_account"]) -> None: ...

global___PermanentLockedAccount = PermanentLockedAccount

@typing_extensions.final
class ClawbackVestingAccount(google.protobuf.message.Message):
    """ClawbackVestingAccount implements the VestingAccount interface. It provides
    an account that can hold contributions subject to "lockup" (like a
    PeriodicVestingAccount), or vesting which is subject to clawback
    of unvested tokens, or a combination (tokens vest, but are still locked).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_VESTING_ACCOUNT_FIELD_NUMBER: builtins.int
    FUNDER_ADDRESS_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    LOCKUP_PERIODS_FIELD_NUMBER: builtins.int
    VESTING_PERIODS_FIELD_NUMBER: builtins.int
    @property
    def base_vesting_account(self) -> global___BaseVestingAccount: ...
    funder_address: builtins.str
    """funder_address specifies the account which can perform clawback."""
    start_time: builtins.int
    @property
    def lockup_periods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Period]:
        """unlocking schedule relative to the BaseVestingAccount start_time."""
    @property
    def vesting_periods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Period]:
        """vesting (i.e. immunity from clawback) schedule relative to the BaseVestingAccount start_time."""
    def __init__(
        self,
        *,
        base_vesting_account: global___BaseVestingAccount | None = ...,
        funder_address: builtins.str = ...,
        start_time: builtins.int = ...,
        lockup_periods: collections.abc.Iterable[global___Period] | None = ...,
        vesting_periods: collections.abc.Iterable[global___Period] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_vesting_account", b"base_vesting_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_vesting_account", b"base_vesting_account", "funder_address", b"funder_address", "lockup_periods", b"lockup_periods", "start_time", b"start_time", "vesting_periods", b"vesting_periods"]) -> None: ...

global___ClawbackVestingAccount = ClawbackVestingAccount



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.capability.v1beta1.capability_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisOwners(google.protobuf.message.Message):
    """GenesisOwners defines the capability owners with their corresponding index."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    INDEX_OWNERS_FIELD_NUMBER: builtins.int
    index: builtins.int
    """index is the index of the capability owner."""
    @property
    def index_owners(self) -> cosmos.capability.v1beta1.capability_pb2.CapabilityOwners:
        """index_owners are the owners at the given index."""
    def __init__(
        self,
        *,
        index: builtins.int = ...,
        index_owners: cosmos.capability.v1beta1.capability_pb2.CapabilityOwners | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["index_owners", b"index_owners"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["index", b"index", "index_owners", b"index_owners"]) -> None: ...

global___GenesisOwners = GenesisOwners

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the capability module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    OWNERS_FIELD_NUMBER: builtins.int
    index: builtins.int
    """index is the capability global index."""
    @property
    def owners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenesisOwners]:
        """owners represents a map from index to owners of the capability index
        index key is string to allow amino marshalling.
        """
    def __init__(
        self,
        *,
        index: builtins.int = ...,
        owners: collections.abc.Iterable[global___GenesisOwners] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["index", b"index", "owners", b"owners"]) -> None: ...

global___GenesisState = GenesisState



import sys

try:
    if sys.version_info >= (3, 8):
        from importlib_metadata import version

        __version__ = version(__package__ or __name__)
    else:
        import pkg_resources

        __version__ = pkg_resources.get_distribution(
            __package__ or __name__).version
except BaseException:
    pass

import google.protobuf.message

ProtobufMessage = google.protobuf.message.Message

import osmosispy.exceptions  # noqa
import osmosispy.pytypes  # noqa
from osmosispy.grpc_client import GrpcClient  # noqa
from osmosispy.pytypes import (  # noqa
    Coin,
    Direction,
    Network,
    NetworkType,
    PoolAsset,
    Side,
    TxConfig,
    TxType,
)
from osmosispy.sdk import Sdk  # noqa
from osmosispy.tx import Transaction  # noqa
from osmosispy.wallet import Address, PrivateKey, PublicKey  # noqa



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgGrantAllowance(google.protobuf.message.Message):
    """MsgGrantAllowance adds permission for Grantee to spend up to Allowance
    of fees from the account of Granter.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    ALLOWANCE_FIELD_NUMBER: builtins.int
    granter: builtins.str
    """granter is the address of the user granting an allowance of their funds."""
    grantee: builtins.str
    """grantee is the address of the user being granted an allowance of another user's funds."""
    @property
    def allowance(self) -> google.protobuf.any_pb2.Any:
        """allowance can be any of basic and filtered fee allowance."""
    def __init__(
        self,
        *,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
        allowance: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allowance", b"allowance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowance", b"allowance", "grantee", b"grantee", "granter", b"granter"]) -> None: ...

global___MsgGrantAllowance = MsgGrantAllowance

@typing_extensions.final
class MsgGrantAllowanceResponse(google.protobuf.message.Message):
    """MsgGrantAllowanceResponse defines the Msg/GrantAllowanceResponse response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgGrantAllowanceResponse = MsgGrantAllowanceResponse

@typing_extensions.final
class MsgRevokeAllowance(google.protobuf.message.Message):
    """MsgRevokeAllowance removes any existing Allowance from Granter to Grantee."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    granter: builtins.str
    """granter is the address of the user granting an allowance of their funds."""
    grantee: builtins.str
    """grantee is the address of the user being granted an allowance of another user's funds."""
    def __init__(
        self,
        *,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee", b"grantee", "granter", b"granter"]) -> None: ...

global___MsgRevokeAllowance = MsgRevokeAllowance

@typing_extensions.final
class MsgRevokeAllowanceResponse(google.protobuf.message.Message):
    """MsgRevokeAllowanceResponse defines the Msg/RevokeAllowanceResponse response type."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MsgRevokeAllowanceResponse = MsgRevokeAllowanceResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/incentives/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from osmosis.incentives import gauge_pb2 as osmosis_dot_incentives_dot_gauge__pb2
from osmosis.lockup import lock_pb2 as osmosis_dot_lockup_dot_lock__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bosmosis/incentives/tx.proto\x12\x12osmosis.incentives\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1eosmosis/incentives/gauge.proto\x1a\x19osmosis/lockup/lock.proto\"\xcc\x02\n\x0eMsgCreateGauge\x12\x14\n\x0cis_perpetual\x18\x01 \x01(\x08\x12\x1f\n\x05owner\x18\x02 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12;\n\rdistribute_to\x18\x03 \x01(\x0b\x32\x1e.osmosis.lockup.QueryConditionB\x04\xc8\xde\x1f\x00\x12Z\n\x05\x63oins\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12L\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1c\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"timestamp\"\x12\x1c\n\x14num_epochs_paid_over\x18\x06 \x01(\x04\"\x18\n\x16MsgCreateGaugeResponse\"\xa0\x01\n\rMsgAddToGauge\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12\x10\n\x08gauge_id\x18\x02 \x01(\x04\x12\\\n\x07rewards\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x17\n\x15MsgAddToGaugeResponse2\xc0\x01\n\x03Msg\x12]\n\x0b\x43reateGauge\x12\".osmosis.incentives.MsgCreateGauge\x1a*.osmosis.incentives.MsgCreateGaugeResponse\x12Z\n\nAddToGauge\x12!.osmosis.incentives.MsgAddToGauge\x1a).osmosis.incentives.MsgAddToGaugeResponseB8Z6github.com/osmosis-labs/osmosis/v14/x/incentives/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.incentives.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/osmosis-labs/osmosis/v14/x/incentives/types'
  _MSGCREATEGAUGE.fields_by_name['owner']._options = None
  _MSGCREATEGAUGE.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _MSGCREATEGAUGE.fields_by_name['distribute_to']._options = None
  _MSGCREATEGAUGE.fields_by_name['distribute_to']._serialized_options = b'\310\336\037\000'
  _MSGCREATEGAUGE.fields_by_name['coins']._options = None
  _MSGCREATEGAUGE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGCREATEGAUGE.fields_by_name['start_time']._options = None
  _MSGCREATEGAUGE.fields_by_name['start_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\020yaml:\"timestamp\"'
  _MSGADDTOGAUGE.fields_by_name['owner']._options = None
  _MSGADDTOGAUGE.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _MSGADDTOGAUGE.fields_by_name['rewards']._options = None
  _MSGADDTOGAUGE.fields_by_name['rewards']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGCREATEGAUGE._serialized_start=198
  _MSGCREATEGAUGE._serialized_end=530
  _MSGCREATEGAUGERESPONSE._serialized_start=532
  _MSGCREATEGAUGERESPONSE._serialized_end=556
  _MSGADDTOGAUGE._serialized_start=559
  _MSGADDTOGAUGE._serialized_end=719
  _MSGADDTOGAUGERESPONSE._serialized_start=721
  _MSGADDTOGAUGERESPONSE._serialized_end=744
  _MSG._serialized_start=747
  _MSG._serialized_end=939
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import tendermint.crypto.proof_pb2
import tendermint.types.validator_pb2
import tendermint.version.types_pb2
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BlockIDFlag:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BlockIDFlagEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BlockIDFlag.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BLOCK_ID_FLAG_UNKNOWN: _BlockIDFlag.ValueType  # 0
    BLOCK_ID_FLAG_ABSENT: _BlockIDFlag.ValueType  # 1
    BLOCK_ID_FLAG_COMMIT: _BlockIDFlag.ValueType  # 2
    BLOCK_ID_FLAG_NIL: _BlockIDFlag.ValueType  # 3

class BlockIDFlag(_BlockIDFlag, metaclass=_BlockIDFlagEnumTypeWrapper):
    """BlockIdFlag indicates which BlcokID the signature is for"""

BLOCK_ID_FLAG_UNKNOWN: BlockIDFlag.ValueType  # 0
BLOCK_ID_FLAG_ABSENT: BlockIDFlag.ValueType  # 1
BLOCK_ID_FLAG_COMMIT: BlockIDFlag.ValueType  # 2
BLOCK_ID_FLAG_NIL: BlockIDFlag.ValueType  # 3
global___BlockIDFlag = BlockIDFlag

class _SignedMsgType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SignedMsgTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SignedMsgType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SIGNED_MSG_TYPE_UNKNOWN: _SignedMsgType.ValueType  # 0
    SIGNED_MSG_TYPE_PREVOTE: _SignedMsgType.ValueType  # 1
    """Votes"""
    SIGNED_MSG_TYPE_PRECOMMIT: _SignedMsgType.ValueType  # 2
    SIGNED_MSG_TYPE_PROPOSAL: _SignedMsgType.ValueType  # 32
    """Proposals"""

class SignedMsgType(_SignedMsgType, metaclass=_SignedMsgTypeEnumTypeWrapper):
    """SignedMsgType is a type of signed message in the consensus."""

SIGNED_MSG_TYPE_UNKNOWN: SignedMsgType.ValueType  # 0
SIGNED_MSG_TYPE_PREVOTE: SignedMsgType.ValueType  # 1
"""Votes"""
SIGNED_MSG_TYPE_PRECOMMIT: SignedMsgType.ValueType  # 2
SIGNED_MSG_TYPE_PROPOSAL: SignedMsgType.ValueType  # 32
"""Proposals"""
global___SignedMsgType = SignedMsgType

@typing_extensions.final
class PartSetHeader(google.protobuf.message.Message):
    """PartsetHeader"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    total: builtins.int
    hash: builtins.bytes
    def __init__(
        self,
        *,
        total: builtins.int = ...,
        hash: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash", b"hash", "total", b"total"]) -> None: ...

global___PartSetHeader = PartSetHeader

@typing_extensions.final
class Part(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    BYTES_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    index: builtins.int
    bytes: builtins.bytes
    @property
    def proof(self) -> tendermint.crypto.proof_pb2.Proof: ...
    def __init__(
        self,
        *,
        index: builtins.int = ...,
        bytes: builtins.bytes = ...,
        proof: tendermint.crypto.proof_pb2.Proof | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["proof", b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bytes", b"bytes", "index", b"index", "proof", b"proof"]) -> None: ...

global___Part = Part

@typing_extensions.final
class BlockID(google.protobuf.message.Message):
    """BlockID"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HASH_FIELD_NUMBER: builtins.int
    PART_SET_HEADER_FIELD_NUMBER: builtins.int
    hash: builtins.bytes
    @property
    def part_set_header(self) -> global___PartSetHeader: ...
    def __init__(
        self,
        *,
        hash: builtins.bytes = ...,
        part_set_header: global___PartSetHeader | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["part_set_header", b"part_set_header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash", b"hash", "part_set_header", b"part_set_header"]) -> None: ...

global___BlockID = BlockID

@typing_extensions.final
class Header(google.protobuf.message.Message):
    """--------------------------------

    Header defines the structure of a Tendermint block header.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    LAST_BLOCK_ID_FIELD_NUMBER: builtins.int
    LAST_COMMIT_HASH_FIELD_NUMBER: builtins.int
    DATA_HASH_FIELD_NUMBER: builtins.int
    VALIDATORS_HASH_FIELD_NUMBER: builtins.int
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: builtins.int
    CONSENSUS_HASH_FIELD_NUMBER: builtins.int
    APP_HASH_FIELD_NUMBER: builtins.int
    LAST_RESULTS_HASH_FIELD_NUMBER: builtins.int
    EVIDENCE_HASH_FIELD_NUMBER: builtins.int
    PROPOSER_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def version(self) -> tendermint.version.types_pb2.Consensus:
        """basic block info"""
    chain_id: builtins.str
    height: builtins.int
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_block_id(self) -> global___BlockID:
        """prev block info"""
    last_commit_hash: builtins.bytes
    """hashes of block data
    commit from validators from the last block
    """
    data_hash: builtins.bytes
    """transactions"""
    validators_hash: builtins.bytes
    """hashes from the app output from the prev block
    validators for the current block
    """
    next_validators_hash: builtins.bytes
    """validators for the next block"""
    consensus_hash: builtins.bytes
    """consensus params for current block"""
    app_hash: builtins.bytes
    """state after txs from the previous block"""
    last_results_hash: builtins.bytes
    """root hash of all results from the txs from the previous block"""
    evidence_hash: builtins.bytes
    """consensus info
    evidence included in the block
    """
    proposer_address: builtins.bytes
    """original proposer of the block"""
    def __init__(
        self,
        *,
        version: tendermint.version.types_pb2.Consensus | None = ...,
        chain_id: builtins.str = ...,
        height: builtins.int = ...,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_block_id: global___BlockID | None = ...,
        last_commit_hash: builtins.bytes = ...,
        data_hash: builtins.bytes = ...,
        validators_hash: builtins.bytes = ...,
        next_validators_hash: builtins.bytes = ...,
        consensus_hash: builtins.bytes = ...,
        app_hash: builtins.bytes = ...,
        last_results_hash: builtins.bytes = ...,
        evidence_hash: builtins.bytes = ...,
        proposer_address: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_block_id", b"last_block_id", "time", b"time", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_hash", b"app_hash", "chain_id", b"chain_id", "consensus_hash", b"consensus_hash", "data_hash", b"data_hash", "evidence_hash", b"evidence_hash", "height", b"height", "last_block_id", b"last_block_id", "last_commit_hash", b"last_commit_hash", "last_results_hash", b"last_results_hash", "next_validators_hash", b"next_validators_hash", "proposer_address", b"proposer_address", "time", b"time", "validators_hash", b"validators_hash", "version", b"version"]) -> None: ...

global___Header = Header

@typing_extensions.final
class Data(google.protobuf.message.Message):
    """Data contains the set of transactions included in the block"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TXS_FIELD_NUMBER: builtins.int
    @property
    def txs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]:
        """Txs that will be applied by state @ block.Height+1.
        NOTE: not all txs here are valid.  We're just agreeing on the order first.
        This means that block.AppHash does not include these txs.
        """
    def __init__(
        self,
        *,
        txs: collections.abc.Iterable[builtins.bytes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["txs", b"txs"]) -> None: ...

global___Data = Data

@typing_extensions.final
class Vote(google.protobuf.message.Message):
    """Vote represents a prevote, precommit, or commit vote from validators for
    consensus.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROUND_FIELD_NUMBER: builtins.int
    BLOCK_ID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_INDEX_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    type: global___SignedMsgType.ValueType
    height: builtins.int
    round: builtins.int
    @property
    def block_id(self) -> global___BlockID:
        """zero if vote is nil."""
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    validator_address: builtins.bytes
    validator_index: builtins.int
    signature: builtins.bytes
    def __init__(
        self,
        *,
        type: global___SignedMsgType.ValueType = ...,
        height: builtins.int = ...,
        round: builtins.int = ...,
        block_id: global___BlockID | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        validator_address: builtins.bytes = ...,
        validator_index: builtins.int = ...,
        signature: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["block_id", b"block_id", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_id", b"block_id", "height", b"height", "round", b"round", "signature", b"signature", "timestamp", b"timestamp", "type", b"type", "validator_address", b"validator_address", "validator_index", b"validator_index"]) -> None: ...

global___Vote = Vote

@typing_extensions.final
class Commit(google.protobuf.message.Message):
    """Commit contains the evidence that a block was committed by a set of validators."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEIGHT_FIELD_NUMBER: builtins.int
    ROUND_FIELD_NUMBER: builtins.int
    BLOCK_ID_FIELD_NUMBER: builtins.int
    SIGNATURES_FIELD_NUMBER: builtins.int
    height: builtins.int
    round: builtins.int
    @property
    def block_id(self) -> global___BlockID: ...
    @property
    def signatures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommitSig]: ...
    def __init__(
        self,
        *,
        height: builtins.int = ...,
        round: builtins.int = ...,
        block_id: global___BlockID | None = ...,
        signatures: collections.abc.Iterable[global___CommitSig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["block_id", b"block_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_id", b"block_id", "height", b"height", "round", b"round", "signatures", b"signatures"]) -> None: ...

global___Commit = Commit

@typing_extensions.final
class CommitSig(google.protobuf.message.Message):
    """CommitSig is a part of the Vote included in a Commit."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCK_ID_FLAG_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    block_id_flag: global___BlockIDFlag.ValueType
    validator_address: builtins.bytes
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    signature: builtins.bytes
    def __init__(
        self,
        *,
        block_id_flag: global___BlockIDFlag.ValueType = ...,
        validator_address: builtins.bytes = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        signature: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_id_flag", b"block_id_flag", "signature", b"signature", "timestamp", b"timestamp", "validator_address", b"validator_address"]) -> None: ...

global___CommitSig = CommitSig

@typing_extensions.final
class Proposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROUND_FIELD_NUMBER: builtins.int
    POL_ROUND_FIELD_NUMBER: builtins.int
    BLOCK_ID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    type: global___SignedMsgType.ValueType
    height: builtins.int
    round: builtins.int
    pol_round: builtins.int
    @property
    def block_id(self) -> global___BlockID: ...
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    signature: builtins.bytes
    def __init__(
        self,
        *,
        type: global___SignedMsgType.ValueType = ...,
        height: builtins.int = ...,
        round: builtins.int = ...,
        pol_round: builtins.int = ...,
        block_id: global___BlockID | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        signature: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["block_id", b"block_id", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_id", b"block_id", "height", b"height", "pol_round", b"pol_round", "round", b"round", "signature", b"signature", "timestamp", b"timestamp", "type", b"type"]) -> None: ...

global___Proposal = Proposal

@typing_extensions.final
class SignedHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_FIELD_NUMBER: builtins.int
    COMMIT_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> global___Header: ...
    @property
    def commit(self) -> global___Commit: ...
    def __init__(
        self,
        *,
        header: global___Header | None = ...,
        commit: global___Commit | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["commit", b"commit", "header", b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commit", b"commit", "header", b"header"]) -> None: ...

global___SignedHeader = SignedHeader

@typing_extensions.final
class LightBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNED_HEADER_FIELD_NUMBER: builtins.int
    VALIDATOR_SET_FIELD_NUMBER: builtins.int
    @property
    def signed_header(self) -> global___SignedHeader: ...
    @property
    def validator_set(self) -> tendermint.types.validator_pb2.ValidatorSet: ...
    def __init__(
        self,
        *,
        signed_header: global___SignedHeader | None = ...,
        validator_set: tendermint.types.validator_pb2.ValidatorSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["signed_header", b"signed_header", "validator_set", b"validator_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["signed_header", b"signed_header", "validator_set", b"validator_set"]) -> None: ...

global___LightBlock = LightBlock

@typing_extensions.final
class BlockMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCK_ID_FIELD_NUMBER: builtins.int
    BLOCK_SIZE_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    NUM_TXS_FIELD_NUMBER: builtins.int
    @property
    def block_id(self) -> global___BlockID: ...
    block_size: builtins.int
    @property
    def header(self) -> global___Header: ...
    num_txs: builtins.int
    def __init__(
        self,
        *,
        block_id: global___BlockID | None = ...,
        block_size: builtins.int = ...,
        header: global___Header | None = ...,
        num_txs: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["block_id", b"block_id", "header", b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_id", b"block_id", "block_size", b"block_size", "header", b"header", "num_txs", b"num_txs"]) -> None: ...

global___BlockMeta = BlockMeta

@typing_extensions.final
class TxProof(google.protobuf.message.Message):
    """TxProof represents a Merkle proof of the presence of a transaction in the Merkle tree."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOT_HASH_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    root_hash: builtins.bytes
    data: builtins.bytes
    @property
    def proof(self) -> tendermint.crypto.proof_pb2.Proof: ...
    def __init__(
        self,
        *,
        root_hash: builtins.bytes = ...,
        data: builtins.bytes = ...,
        proof: tendermint.crypto.proof_pb2.Proof | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["proof", b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "proof", b"proof", "root_hash", b"root_hash"]) -> None: ...

global___TxProof = TxProof



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.params.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC querier service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        cosmos.params.v1beta1.query_pb2.QueryParamsRequest,
        cosmos.params.v1beta1.query_pb2.QueryParamsResponse,
    ]
    """Params queries a specific parameter of a module, given its subspace and
    key.
    """

class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""

    @abc.abstractmethod
    def Params(
        self,
        request: cosmos.params.v1beta1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.params.v1beta1.query_pb2.QueryParamsResponse:
        """Params queries a specific parameter of a module, given its subspace and
        key.
        """

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...
